@@ -321,6 +321,15 @@ class StatisticalTests(unittest.TestCase):
       with_array = naf.fit(np.array(T),np.array(C)).cumulative_hazard_.values
       npt.assert_array_equal(with_list,with_array)
 
+  def test_timeline_to_NelsonAalenFitter(self):
+      T = [2,3,1.,6,5.]
+      C = [1,0,0,1,1]
+      timeline = [2,3,4.,1.,6,5.]
+      naf = NelsonAalenFitter()
+      with_list = naf.fit(T,C,timeline=timeline).cumulative_hazard_.values
+      with_array = naf.fit(T,C,timeline=np.array(timeline)).cumulative_hazard_.values
+      npt.assert_array_equal(with_list,with_array)
+
   def test_pairwise_allows_dataframes(self):
       N = 100
       df = pd.DataFrame(np.empty((N,3)), columns=["T", "C", "group"])
@@ -349,12 +358,27 @@ class StatisticalTests(unittest.TestCase):
       kmf, naf = KaplanMeierFitter(), NelsonAalenFitter()
       T = [1,2,3,4]
       kmf.fit(T), naf.fit(T)
-      assert(int(kmf.survival_function_.index[0])==0)
-      assert(int(naf.cumulative_hazard_.index[0])==0)
+      self.assertTrue(int(kmf.survival_function_.index[0])==0)
+      self.assertTrue(int(naf.cumulative_hazard_.index[0])==0)
 
       kmf.fit(T, insert_0=False), naf.fit(T, insert_0=False)
-      assert(int(kmf.survival_function_.index[0])==1)
-      assert(int(naf.cumulative_hazard_.index[0])==1)
+      self.assertTrue(int(kmf.survival_function_.index[0])==1)
+      self.assertTrue(int(naf.cumulative_hazard_.index[0])==1)
+
+  def test_subtraction_function(self):
+      
+      kmf = KaplanMeierFitter()
+      kmf.fit(waltonT)
+      npt.assert_array_almost_equal( kmf.subtract(kmf).sum().values, 0.0 )
+  
+  def test_divide_function(self):
+      
+      kmf = KaplanMeierFitter()
+      kmf.fit(waltonT)
+      npt.assert_array_almost_equal( np.log(kmf.divide(kmf)).sum().values, 0.0 )
+
+
+
 
   def kaplan_meier(self, censor=False):
       km = np.zeros((len(self.lifetimes.keys()),1))
